"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var url_1 = require("url");
var link = function (href, text) { return "<a href=\"" + href + "\">" + text + "</a>"; };
var ensureUrlEndsWithSlash = function (url) {
    if (!url.endsWith('/')) {
        return url.concat('/');
    }
    return url;
};
/**
 * A Danger plugin to add a JIRA issue link to the Danger pull request comment.
 * If a pull request title does not contain the supplied JIRA issue identifier (e.g. ABC-123),
 * then Danger will comment with a warning on the pull request asking the developer
 * to include the JIRA issue identifier in the pull request title.
 */
function jiraIssue(options) {
    var _a = options || {}, _b = _a.key, key = _b === void 0 ? '' : _b, _c = _a.url, url = _c === void 0 ? '' : _c, _d = _a.emoji, emoji = _d === void 0 ? ':link:' : _d;
    if (!url) {
        throw Error("'url' missing - must supply JIRA installation URL");
    }
    if (!key) {
        throw Error("'key' missing - must supply JIRA issue key");
    }
    var jiraKeyRegex = new RegExp("(" + key + "-[0-9]+)", 'g');
    var match;
    var jiraIssues = [];
    // tslint:disable-next-line:no-conditional-assignment
    while ((match = jiraKeyRegex.exec(danger.github.pr.title)) != null) {
        jiraIssues.push(match[0]);
    }
    if (jiraIssues.length > 0) {
        var jiraUrls = jiraIssues
            .map(function (issue) { return link(url_1.resolve(ensureUrlEndsWithSlash(url), issue), issue); })
            .join(', ');
        message(emoji + " " + jiraUrls);
    }
    else {
        warn("Please add the JIRA issue key to the PR title (e.g. " + key + "-123)");
    }
}
exports.default = jiraIssue;
